'use strict'

var assert = require('assert')
var Registry = require('../')
var PropertiesReader = require('properties-reader')

describe('Registry tests', function() {
  var reg = new Registry()

  it('Capabilities lookup from CADC', function(done) {
    reg.capabilityURLs().then(function(results) {
      var capabilityURLs = results.data
      assert.ok(capabilityURLs, `Capability URLs should have some value`)

      var properties = new PropertiesReader().read(capabilityURLs)

      done(
        properties.get('ivo://cadc.nrc.ca/tap') !==
        'http://www.cadc-ccda.hia-iha.nrc-cnrc.gc.ca/tap/capabilities'
          ? `Wrong value for TAP Service (Actual is ${properties.get(
              'ivo://cadc.nrc.ca/tap'
            )}`
          : undefined
      )
    })
  })

  it('HTTP service URL lookup', function(done) {
    reg
      .serviceURL('ivo://cadc.nrc.ca/tap', 'ivo://ivoa.net/std/TAP', false)
      .then(function(serviceURL) {
        if ('http://www.cadc-ccda.hia-iha.nrc-cnrc.gc.ca/tap' !== serviceURL) {
          done(`Wrong Service URL returned >> (${serviceURL})`)
        } else {
          done()
        }
      })
  })

  it('HTTPS service URL lookup', function(done) {
    reg
      .serviceURL('ivo://cadc.nrc.ca/tap', 'ivo://ivoa.net/std/TAP', true)
      .then(function(serviceURL) {
        if ('https://www.cadc-ccda.hia-iha.nrc-cnrc.gc.ca/tap' !== serviceURL) {
          done(`Wrong secure service URL returned >> (${serviceURL})`)
        } else {
          done()
        }
      })
  })
})
